<?php
/**
 * This class simply puts HTML code / JavaScript code or CSS code out to the
 * browser
 *
 * @author		Roland Haeder <webmaster@mxchange.org>
 * @version		0.3.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.mxchange.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class WebOutput extends BaseFrameworkSystem implements OutputStreamer {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $webInstance = null;

	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setPartDescr("Web-Ausgabe-Handler");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param		$contentType		A valid content-type
	 * @return	$debugInstance		An instance of this middleware class
	 */
	public final static function createWebOutput ($contentType) {
		// Is there no instance?
		if (is_null(self::$webInstance)) {
			// Cast the content-type to string and trim it
			$contentType = (string) $contentType;
			$contentType = trim($contentType);

			// Set the content type
			if (!empty($contentType)) {
				@header(sprintf("Content-type: %s",
					$contentType
				));
			}

			// Get a new instance and set it
			self::$webInstance = new WebOutput();
		}

		// Return instance
		return self::$webInstance;
	}

	/**
	 * Assigns a variable for output
	 *
	 * @param		$var		The variable we shall assign
	 * @param		$value	The value to store in the variable
	 * @return	void
	 */
	public function assignVariable($var, $value) {
		// Stub message because we don't have it here
		trigger_error(__METHOD__.": Stub!");
	}

	/**
	 * Output the code
	 *
	 * @return	void
	 */
	public final function output ($outStream=false) {
		print $outStream;
	}
}

// [EOF]
?>
